@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: semigroupoids
-version: 1.3.4
-id: semigroupoids-1.3.4-f6cac02bc81f1b90cb5781134a5d6e49
+version: 3.0.3
+id: semigroupoids-3.0.3-3f51386efb52c19d1b27985adc9dde05
 
 license: BSD3
 copyright: Copyright (C) 2011 Edward A. Kmett
@@ -32,7 +32,7 @@ description: Provides a wide array of semigroupoids and operations for working w
              >                                 Bind ---------> Monad -------> MonadPlus          Arrow
              >
              .
-             Apply, Bind, and Extract give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
+             Apply, Bind, and Extend (not shown) give rise the Static, Kleisli and Cokleisli semigroupoids respectively.
              .
              This lets us remove many of the restrictions from various monad transformers
              as in many cases the binding operation or @\<*\>@ operation does not require them.
@@ -46,29 +46,29 @@ pkgpath: devel/hs-semigroupoids
 exposed: True
 exposed-modules: Data.Functor.Alt Data.Functor.Apply
                  Data.Functor.Bind Data.Functor.Bind.Trans Data.Functor.Plus
-                 Data.Semigroup.Foldable Data.Semigroup.Traversable
-                 Data.Semigroupoid Data.Semigroupoid.Dual Data.Semigroupoid.Static
-                 Data.Traversable.Instances
+                 Data.Functor.Extend Data.Semigroup.Foldable
+                 Data.Semigroup.Traversable Data.Semigroupoid Data.Semigroupoid.Dual
+                 Data.Semigroupoid.Static Data.Traversable.Instances
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/semigroupoids-1.3.4
-library-dirs: /usr/local/lib/ghc/semigroupoids-1.3.4
-hs-libraries: HSsemigroupoids-1.3.4
+import-dirs: /usr/local/lib/ghc/semigroupoids-3.0.3
+library-dirs: /usr/local/lib/ghc/semigroupoids-3.0.3
+hs-libraries: HSsemigroupoids-3.0.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         comonad-1.1.1.6-1ab55e9c35a79b8bc4ee534d99a53a51
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         contravariant-0.2.0.2-a904f04c113b714e9e395ee37d9f46c4
-         semigroups-0.8.3.2-08bd9e08e0f404cc4af18eab242e78de
-         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
+depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         comonad-3.0.3-97c2b9aaa661ce271befc6b439457331
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         contravariant-0.2.0.2-e8d546716fa930b4966f18f08040d2fa
+         semigroups-0.9.2-51d976447c6408479cabc66ac9867fc6
+         transformers-0.3.0.0-948c0bbaafc952a144be4248ffa27cb1
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-semigroupoids-1.3.4/html/semigroupoids.haddock
-haddock-html: /usr/local/share/doc/hs-semigroupoids-1.3.4/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-semigroupoids-3.0.3/html/semigroupoids.haddock
+haddock-html: /usr/local/share/doc/hs-semigroupoids-3.0.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
